ast_rewrite_small_commit_intervals

Function ast_rewrite_small_commit_intervals 

fn ast_rewrite_small_commit_intervals(
    stmt: &mut Statement<Raw>,
) -> Result<(), Error>
Planning enforces a 1 second minimum COMMIT INTERVAL, but smaller intervals used to be accepted (and a sub-millisecond one left the sink unable to ever commit). Rewrite any persisted smaller interval to 1s so the sink still plans after an upgrade.

COMMIT INTERVAL is a generic CREATE SINK option in the grammar, but only Iceberg sinks accept it and only Iceberg planning enforces the 1s floor.